@@ -20,6 +20,7 @@ from soaplib.service import rpc
 import sys
 import pickle, os
 from calculate.lib.datavars import SourceReadonlyVariable
+from collections import Mapping
 
 from calculate.lib.cl_lang import setLocalTranslate
 setLocalTranslate('cl_core3',sys.modules[__name__])
@@ -79,7 +80,7 @@ class DataVarsSerializer(ClassSerializer):
         if "choice" in varObj.type or "file" in varObj.type or \
             varObj.element == "radio":
             choice,comments = varObj.parent.ChoiceAndComments(varObj.name)
-            return self.arrayString(choice),self.arrayString(comments)
+            return self.arrayString(choice), self.arrayString(comments)
         else:
             return (None,None)
 
@@ -164,6 +165,7 @@ class Table(DataVarsSerializer):
             self.onClick = onClick
             self.addAction = addAction
 
+
 class Option(DataVarsSerializer):
     shortopt = String
     longopt = String
@@ -213,8 +215,8 @@ class Field(DataVarsSerializer):
             self.help = varObj.help
             self.element = varObj.element or \
                            self.elementByType(self.type)
+            self.label = varObj.label or varObj.name
             if not onlyhelp or varObj.syntax or self.type == "table":
-                self.label = varObj.label or varObj.name
                 if inbrief:
                     self.uncompatible = ""
                 else:
@@ -280,10 +282,9 @@ class GroupField(DataVarsSerializer):
                     if not var in groupDepVars:
                         groupDepVars.append(var)
 
-            uniqBrief = list((set(info['brief']) | set(info['brief_force'])) - \
-                            set(info['normal'])-
-                             set(info['expert']))
             if brief:
+                uniqBrief = list(info['brief']) + [x for x in info['brief_force']
+                                             if x not in info['brief']]
                 for varname in uniqBrief:
                     varObj = dv.getInfo(varname)
                     inbrief = varname in info['brief_force']
@@ -292,7 +293,9 @@ class GroupField(DataVarsSerializer):
                                              varObj=varObj,
                                              groupVars=groupDepVars,
                                              onlyhelp=onlyhelp))
-            for varname in info['normal']:
+            else:
+                uniqBrief = []
+            for varname in (x for x in info['normal'] if x not in uniqBrief):
                 inbrief = brief and varname in info['brief_force']
                 if brief and 'hide' in info and  varname in info['hide']:
                     continue
@@ -303,7 +306,7 @@ class GroupField(DataVarsSerializer):
                                          groupVars=groupDepVars,
                                          onlyhelp=onlyhelp))
             if info['expert']:
-                for varname in info['expert']:
+                for varname in (x for x in info['expert'] if x not in uniqBrief):
                     if expert == True or \
                         expert == None and dv.getInfo(varname).wasSet:
                         self.fields.append(Field(name = "expert",
@@ -393,12 +396,14 @@ class ViewInfo(DataVarsSerializer):
                           head = [i['name'] for i in groupInfo],
                           fields = [i.get('image','') for i in groupInfo]+\
                                    [image_value],
-                          body = [list(i['normal'])+[""]+list(i['expert'])
-                                                  for i in groupInfo]))])
+                          body=[self.arrayString(
+                              list(i['normal']) + [""] + list(i['expert']))
+                                for i in groupInfo]))])
 
 #element = ['table', 'radio', 'combo', 'comboEdit', 'multichoice', \
            #'multichoice_add', 'check', 'check_tristate', 'expert', 'input']
 
+
 class ViewParams(ClassSerializer):
     """
     Struct for _view methods
@@ -409,20 +414,26 @@ class ViewParams(ClassSerializer):
     onlyhelp = Boolean      # request params for only help
     clienttype = String     # type of client "gui","console"
 
-################# MESSAGE ####################
 
+################# MESSAGE ####################
 class ReturnedMessage(ClassSerializer):
     type = String
     field = String
     message = String
     expert = Boolean
+    field_obj = Field
+
 
     def __init__(self, type = None, field = None, message = None,
-                 expert = False):
+                 expert = False, field_obj = None):
         self.type = type
         self.field = field
         self.message = message
         self.expert = expert
+        if field_obj:
+            self.field_obj = Field(dv=field_obj.parent, varObj=field_obj)
+        else:
+            self.field_obj = None
 
 class Message(ClassSerializer):
     type = String
@@ -430,14 +441,17 @@ class Message(ClassSerializer):
     id = Integer
     result = Boolean
     onlyShow = String
+    default = String
 
-    def __init__(self, type = 'normal', message = None, id = None,
-                 result = None, onlyShow = None):
+    def __init__(self, type='normal', message=None, id=None,
+                 result=None, onlyShow=None, default=None):
         self.type = type
         self.message = message
         self.id = id
         self.result = result
         self.onlyShow = onlyShow
+        self.default = default
+
 
 class ReturnProgress(ClassSerializer):
     percent = Integer
@@ -449,9 +463,11 @@ class ReturnProgress(ClassSerializer):
         self.short_message = short_message
         self.long_message = long_message
 
+
 class Frame(ClassSerializer):
     values = Array (Message)
 
+
 # get and send client messages
 class CoreWsdl:
     perm_denied = []
@@ -522,10 +538,12 @@ class CoreWsdl:
                 checkall = info.CheckAll
             errors = map(lambda x:ReturnedMessage(**x),
                      dv.checkGroups(info,allvars=checkall or not checkonly))
+            #if dv.Get('cl_env_debug_set') == 'on':
+            #    dv.printGroup(info)
             if errors:
                 return errors
             if checkonly:
-                returnmess = ReturnedMessage(type = '', message = None)
+                returnmess = ReturnedMessage(type='', message=None)
                 return [returnmess]
             if not actionClass:
                 return []
@@ -686,3 +704,100 @@ class CoreWsdl:
     #@Dec.check_permissions()
     def send_message ( self, sid, pid, text):
         return self.client_send_message (sid, pid, text)
+
+
+class WsdlAdapter(object):
+    adapted_class = None
+
+    def __init__(self, source):
+        self.source = source
+
+    @classmethod
+    def from_detect(cls, source):
+        if isinstance(source, (cls.adapted_class, WsdlAdapter)):
+            return source
+        else:
+            return cls(source)
+
+    def __getattr__(self, item):
+        return getattr(self.source, item)
+
+    @staticmethod
+    def Array(field, field_type):
+        def wrapper(self):
+            if getattr(self.source, field):
+                return [field_type(x)
+                        for x in getattr(getattr(self.source, field),
+                                         field_type.__name__[:-7])]
+            else:
+                return []
+
+        return property(wrapper)
+
+    @staticmethod
+    def StringArray(field):
+        def wrapper(self):
+            source_field = getattr(self.source, field)
+            return source_field.string if source_field else []
+
+        return property(wrapper)
+
+
+class ChoiceValueAdapter(WsdlAdapter):
+    adapted_class = ChoiceValue
+
+    values = WsdlAdapter.StringArray("values")
+
+    comments = WsdlAdapter.StringArray("comments")
+
+    onChanged = WsdlAdapter.StringArray("onChanged")
+
+
+class TableAdapter(WsdlAdapter):
+    adapted_class = Table
+
+    fields = WsdlAdapter.StringArray("fields")
+    head = WsdlAdapter.StringArray("head")
+
+    @property
+    def body(self):
+        if hasattr(self.source.body, 'stringArray'):
+            return [row.string
+                    for row in self.source.body.stringArray
+                    if hasattr(row, "string")]
+        return []
+
+    values = WsdlAdapter.Array("values", ChoiceValueAdapter)
+
+
+class FieldAdapter(WsdlAdapter):
+    adapted_class = Field
+
+    choice = WsdlAdapter.StringArray("choice")
+    listvalue = WsdlAdapter.StringArray("listvalue")
+    comments = WsdlAdapter.StringArray("comments")
+
+    @property
+    def tablevalue(self):
+        return TableAdapter(self.source.tablevalue)
+
+
+class GroupFieldAdapter(WsdlAdapter):
+    adapted_class = GroupField
+
+    fields = WsdlAdapter.Array("fields", FieldAdapter)
+
+
+class ViewInfoAdapter(WsdlAdapter):
+    adapted_class = ViewInfo
+
+    groups = WsdlAdapter.Array("groups", GroupFieldAdapter)
+
+
+class ArrayReturnedMessage(WsdlAdapter):
+    @classmethod
+    def from_detect(cls, source):
+        if isinstance(source, (list,tuple)):
+            return source
+        else:
+            return source.ReturnedMessage
