@@ -1,6 +1,6 @@
 #-*- coding: utf-8 -*-
 
-# Copyright 2012 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2012-2013 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -21,23 +21,19 @@ from calculate.core.datavars import DataVarsCore
 from calculate.lib.cl_lang import setLocalTranslate
 setLocalTranslate('cl_core3',sys.modules[__name__])
 
-# clear server files after restart
-def clean (SID_FILE, PID_FILE, SID_PID, SIDS_DIR, PIDS_DIR):
-    if os.path.exists(SID_FILE):
-        os.unlink(SID_FILE)
-    if os.path.exists(PID_FILE):
-        os.unlink(PID_FILE)
-    if os.path.exists(SID_PID):
-        os.unlink(SID_PID)
 
-    if os.path.isdir(SIDS_DIR):
-        for filename in glob.glob(os.path.join(SIDS_DIR, "*.sid")):
-            os.unlink (filename)
-            if os.path.exists(filename):
-                print 'Not deleted file %s!!!' %filename
-    if os.path.isdir(PIDS_DIR):
-        for filename in glob.glob(os.path.join(PIDS_DIR, "*.pid")):
-            os.unlink (filename)    
+def clean(sid_file, pid_file, sid_pid, sids_dir, pids_dir):
+    """
+    Удалить все файлы сервера после перезапуска
+    """
+    for fn in (sid_file, pid_file, sid_pid):
+        if os.path.exists(fn):
+            os.unlink(fn)
+
+    for dn in (sids_dir, pids_dir):
+        if os.path.isdir(dn):
+            for filename in glob.glob(os.path.join(dn, "*.sid")):
+                os.unlink(filename)
 
 class CoreWsdl:
     # watch for process
@@ -125,46 +121,6 @@ def monitor(certbase, SID_FILE):
         except:
             return 1
         
-        ## check certificate
-        ##try:
-        #if not os.path.exists(CERT_FILE):
-            #temp = open(CERT_FILE, 'w')
-            #temp.close()
-        
-        #rst = []
-        #CERT_FILE_T = certbase + '_temp'
-        #fc = open(CERT_FILE, 'r')
-        #fct = open(CERT_FILE_T, 'w')
-        #while 1:
-            #try:
-                ## Считать по одной строке
-                #list_cert = pickle.load(fc)
-            #except:
-                #break
-            ## Сколько существует certificate
-            #delta = datetime.datetime.now() - list_cert["date"]
-            ## Если не устарел, то оставить
-            #if (delta.seconds < cert_live * 60):
-                #pickle.dump(list_cert, fct)
-            #else:
-                #cert_met = serv_get_methods(list_cert["cert"])
-                #if cert_met[0] != "No Method":
-                    #pickle.dump(list_cert, fct)
-        #fc.close()
-        #fct.close()
-        
-        ## Скопировать всё из временного файла
-        #fct = open(CERT_FILE_T, 'rb')
-        #fc = open(CERT_FILE, 'wb')
-        #fct.seek(0)
-        #fc.write(fct.read())
-        #fct.close()
-        #fc.close()
-        
-        ## Удалить временный файл
-        #os.unlink(CERT_FILE_T)
-        ##except:
-            ##print _("file %s not exists") % CERT_FILE
         # Частота проверки
         time.sleep(60 * period)
 
@@ -219,38 +175,3 @@ def sid_monitor(SID_FILE, SIDS_DIR):
             pass
         # check period
         time.sleep(period)
-
-# get available methods for performance
-# for delete old certificates with zero's rights
-
-#def serv_get_methods():
-    #curThread = threading.currentThread()
-    #certificate = curThread.client_cert
-    #if certificate == None:
-        #return -3
-    
-    #from cert_cmd import find_cert_id
-    #cert_id = find_cert_id(cert, self.data_path, self.certbase)
-    
-    #results = []
-    #cert_id = int(cert_id)
-    #if cert_id > 0:
-        #cert_id = str(cert_id)
-        ## open rights file
-        #with open(RIGHT_FILE) as fd:
-            #t = fd.read()
-            ## See each line
-            #for line in t.splitlines():
-                ## and each word in line
-                #words = line.split()
-                #for word in words:
-                    ## if in line present certificate id
-                    #if cert_id == word:
-                        ## add name available method
-                        #results.append(words[0])
-        #fd.close()
-    
-    #if results == []:
-        #results.append("No Methods")
-    
-    #return results
