@@ -1,6 +1,6 @@
 #-*- coding: utf-8 -*-
 
-# Copyright 2010-2012 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2011-2013 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -13,12 +13,6 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-#   mode -     read only or writeable variable
-#   value    - default variable value
-#   select   - list of posible values for variable
-#   hide - flag, if it is True, then the variable is not printable
-#   printval - print value of variable
-
 from calculate.lib.datavars import Variable,ReadonlyVariable,VariableError
 import os, glob, sys
 try:
@@ -27,11 +21,11 @@ except:
     OpenSSL = None
 
 from calculate.lib.cl_lang import setLocalTranslate
-from calculate.lib.utils.files import readLinesFile
+from calculate.lib.utils.files import readLinesFile, pathJoin
 #from calculate.api.cert_cmd import find_id_cert
 setLocalTranslate('cl_core3',sys.modules[__name__])
 
-class VariableClAllReqId(Variable):
+class VariableClListReqId(Variable):
     def get(self):
         data_path = self.Get('cl_core_data')
         result = []
@@ -53,16 +47,18 @@ class VariableClReqId(Variable):
     type = "choice"
     opt = ["-r"]
     metavalue = "REQ_ID"
-    untrust = True
+    untrusted = True
 
     def init(self):
         self.help = _("request identifier")
         self.label = _("Request identifier")
 
     def choice(self):
-        return self.Get('cl_all_req_id')
+        return self.Get('cl_list_req_id')
 
     def check(self, req_id):
+        if not req_id:
+            raise VariableError(_("The request ID is a required parameter"))
         try:
             int(req_id)
         except (ValueError, TypeError):
@@ -78,7 +74,7 @@ class VariableClReqId(Variable):
 
 class VariableClPageLimit(Variable):
     """
-    Certificate Identification
+    Ограничение ????
     """
     type = "int"
     opt = ["--page-limit"]
@@ -97,7 +93,7 @@ class VariableClPageLimit(Variable):
 
 class VariableClPageCount(Variable):
     """
-    Certificate Identification
+    Количество записей на страницу
     """
     type = "int"
     opt = ["--page-count"]
@@ -108,30 +104,40 @@ class VariableClPageCount(Variable):
         self.help = _("set the page count value")
         self.label = _("Page count")
 
-    def check(self, count):
-        try:
-            int(count)
-        except ValueError:
-            raise VariableError(_("The count number must be int"))
+    def get(self):
+        return self.Get('cl_page_max')
+
+    def set(self,value):
+        if not value or int(value) <= 0:
+            value = self.Get('cl_page_max')
+        return value
 
 class VariableClPageOffset(Variable):
     """
-    Certificate Identification
+    Смещение по записям относительно начала
     """
     type = "int"
     opt = ["--page-offset"]
     metavalue = "PAGE_OFFSET"
     element = 'input'
+    value = "0"
 
     def init(self):
         self.help = _("set the page offset value")
         self.label = _("Page offset")
 
-    def check(self, offset):
-        try:
-            int(offset)
-        except ValueError:
-            raise VariableError(_("The offset number must be int"))
+    def set(self,value):
+        max_id = int(self.Get('cl_page_max'))
+        return max(0,min(int(value),max_id-1))
+
+class VariableClPageMax(ReadonlyVariable):
+    """
+    Максимальное количество записей
+    """
+    type = "int"
+
+    def get(self):
+        return "0"
 
 class VariableClReqBaseData(Variable):
     """
@@ -151,9 +157,7 @@ class VariableClReqData(Variable):
     """
     def get(self):
         req_id = self.Get('cl_req_id')
-        data_path = self.Get('cl_core_data')
-        
-        req_file =  data_path + '/client_certs/%s.csr' %req_id
+        req_file =  self.Get('cl_req_csr_path')
         if OpenSSL and  os.path.exists(req_file):
             fp = open(req_file, 'r')
             request = fp.read()
@@ -258,13 +262,14 @@ class VariableClReqGroup(Variable):
     type = "choice"
     opt = ["-g"]
     metavalue = "REQ_GROUP"
+    untrusted = True
 
     def init(self):
         self.help = _("set the certificate group")
         self.label = _("Certificate group")
 
     def choice(self):
-        group_rights = self.Get('cl_core_group_rights')
+        group_rights = self.Get('cl_core_group_rights_path')
 
         t = open(group_rights, 'r').read()
         result = []
@@ -279,9 +284,8 @@ class VariableClReqGroup(Variable):
 
     def get(self):
         req_id = self.Get('cl_req_id')
-        data_path = self.Get('cl_core_data')
         
-        cert_file =  data_path + '/client_certs/%s.crt' %req_id
+        cert_file =  self.Get('cl_req_crt_path')
         if OpenSSL is None:
             return ""
         try:
@@ -296,7 +300,9 @@ class VariableClReqGroup(Variable):
             return ""
 
     def check(self, group):
-        group_rights = self.Get('cl_core_group_rights')
+        if not group:
+            raise VariableError(_("Group permissions is a required parameter"))
+        group_rights = self.Get('cl_core_group_rights_path')
 
         if group == 'all':
             return
@@ -308,3 +314,19 @@ class VariableClReqGroup(Variable):
             if group == words[0]:
                 return
         raise VariableError(_("Group %s does not exist") %group)
+
+class VariableClReqCrtPath(ReadonlyVariable):
+    """
+    Путь до сертификата при использовании запроса на сертификат
+    """
+    def get(self):
+        return pathJoin(self.Get('cl_core_client_certs_path'),
+                        '%s.crt'%self.Get('cl_req_id'))
+
+class VariableClReqCsrPath(ReadonlyVariable):
+    """
+    Путь до запроса
+    """
+    def get(self):
+        return pathJoin(self.Get('cl_core_client_certs_path'),
+                        '%s.csr'%self.Get('cl_req_id'))
