@@ -51,7 +51,7 @@ class Wsdl(WsdlBase):
         # категория метода
         'category':__('Configuration'),
         # заголовок метода 
-        'title':__("Configure a package"),
+        'title':__("Configure a Package"),
         # иконка для графической консоли
         'image':'preferences-desktop-default-applications',
         # метод присутствует в графической консоли
@@ -76,9 +76,10 @@ class Wsdl(WsdlBase):
                 normal=('cl_core_pkg_name',),
                 expert=('cl_core_pkg_category', 'cl_core_pkg_version',
                         'cl_core_pkg_slot', 'cl_core_pkg_path',
+                        'cl_templates_locate',
                         'cl_core_pkg_system_set', 'cl_core_pkg_desktop_set',
                         'cl_core_pkg_root_set',
-                        'cl_templates_locate','cl_verbose_set',
+                        'cl_verbose_set',
                         'cl_dispatch_conf'),
                 next_label=_("Setup"))]},
         #
@@ -125,9 +126,9 @@ class Wsdl(WsdlBase):
         # идентификатор метода
         'method_name':"core_dispatch",
         # категория метода
-        'category':__('Configuration'),
+        'category':__('Update'),
         # заголовок метода 
-        'title':__("Dispatch-conf"),
+        'title':__("Update settings"),
         # иконка для графической консоли
         'image':'computer',
         # метод в графической консоли
@@ -157,7 +158,7 @@ class Wsdl(WsdlBase):
         # категория метода
         'category':__('Utilities'),
         # заголовок метода 
-        'title':__("Show certificates"),
+        'title':__("Show Certificates"),
         # иконка для графической консоли
         'image':'certificate-server,application-certificate',
         # метод в графической консоли
@@ -189,7 +190,7 @@ class Wsdl(WsdlBase):
         # категория метода
         #'category':__('Utilities'),
         # заголовок метода 
-        'title':__("Certificate details"),
+        'title':__("Certificate Details"),
         # иконка для графической консоли
         'image':None,
         # метод в графической консоли
@@ -220,7 +221,7 @@ class Wsdl(WsdlBase):
         # категория метода
         'category':__('Utilities'),
         # заголовок метода 
-        'title':__("Show groups"),
+        'title':__("Show Groups"),
         # иконка для графической консоли
         'image':'user-group-properties,view-certificate-import,'
                 'application-certificate',
@@ -253,7 +254,7 @@ class Wsdl(WsdlBase):
         # категория метода
         #'category':__('Utilities'),
         # заголовок метода 
-        'title':__("Group details"),
+        'title':__("Group Details"),
         # иконка для графической консоли
         'image':None,
         # метод в графической консоли
@@ -288,7 +289,7 @@ class Wsdl(WsdlBase):
         # категория метода
         #'category':__('Utilities'),
         # заголовок метода 
-        'title':__("Modify group"),
+        'title':__("Modify Group"),
         # иконка для графической консоли
         'image':None,
         # метод в графической консоли
@@ -322,7 +323,7 @@ class Wsdl(WsdlBase):
         # категория метода
         #'category':__('Utilities'),
         # заголовок метода 
-        'title':__("Add a group"),
+        'title':__("Add a Group"),
         # иконка для графической консоли
         'image':None,
         # метод в графической консоли
@@ -354,7 +355,7 @@ class Wsdl(WsdlBase):
         # категория метода
         #'category':__('Utilities'),
         # заголовок метода 
-        'title':__("Delete the group"),
+        'title':__("Delete the Group"),
         # иконка для графической консоли
         'image':None,
         # метод в графической консоли
@@ -386,7 +387,7 @@ class Wsdl(WsdlBase):
         # категория метода
         'category':__('Utilities'),
         # заголовок метода 
-        'title':__("Show requests"),
+        'title':__("Show Requests"),
         # иконка для графической консоли
         'image':'view-certificate-import',
         # метод в графической консоли
@@ -418,7 +419,7 @@ class Wsdl(WsdlBase):
         # категория метода
         #'category':__('Utilities'),
         # заголовок метода 
-        'title':__("Request details"),
+        'title':__("Request Details"),
         # иконка для графической консоли
         'image':None,
         # метод в графической консоли
@@ -455,7 +456,7 @@ class Wsdl(WsdlBase):
         # категория метода
         #'category':__('Utilities'),
         # заголовок метода 
-        'title':__("Delete the request"),
+        'title':__("Delete the Request"),
         # иконка для графической консоли
         'image':None,
         # метод в графической консоли
@@ -487,7 +488,7 @@ class Wsdl(WsdlBase):
         # категория метода
         #'category':__('Utilities'),
         # заголовок метода 
-        'title':__("Confirm the request"),
+        'title':__("Confirm the Request"),
         # иконка для графической консоли
         'image':None,
         # метод в графической консоли
@@ -519,7 +520,7 @@ class Wsdl(WsdlBase):
         # категория метода
         'category':__('Utilities'),
         # заголовок метода 
-        'title':__("Setup variables"),
+        'title':__("Setup Variables"),
         # иконка для графической консоли
         'image':'applications-system',
         # метод в графической консоли
@@ -551,7 +552,7 @@ class Wsdl(WsdlBase):
         # категория метода
         'category':__('Utilities'),
         # заголовок метода 
-        'title':__("View variables"),
+        'title':__("View Variables"),
         # иконка для графической консоли
         'image':'application-system',
         # метод в графической консоли
@@ -583,7 +584,7 @@ class Wsdl(WsdlBase):
         # категория метода
         'category':__('Utilities'),
         # заголовок метода 
-        'title':__("Custom action"),
+        'title':__("Custom Action"),
         # иконка для графической консоли
         'image':'gnome-desktop-config,desktop-config',
         # метод в графической консоли
